Alias

Enum Alias 

#[non_exhaustive]
pub enum Alias {
Show 42 variants A, B, C, Ch, Cr, D, E, Ee, F, G, Gh, H, Hh, I, Ii, J, Jy, K, K2, Kh, L, Lh, Lvs, M, N, Ng, Ny, O, Oe, P, R, Rh, S, Sbm, Sh, T, U, Ue, W, Y, Z, Zr,
}
A letter alias (phonemic short name, locale-relative); as_str() is the data-file name (a, oe, k2, …).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


A

Letter alias a.



B

Letter alias b.



C

Letter alias c.



Ch

Letter alias ch.



Cr

Letter alias cr.



D

Letter alias d.



E

Letter alias e.



Ee

Letter alias ee.



F

Letter alias f.



G

Letter alias g.



Gh

Letter alias gh.



H

Letter alias h.



Hh

Letter alias hh.



I

Letter alias i.



Ii

Letter alias ii.



J

Letter alias j.



Jy

Letter alias jy.



K

Letter alias k.



K2

Letter alias k2.



Kh

Letter alias kh.



L

Letter alias l.



Lh

Letter alias lh.



Lvs

Letter alias lvs.



M

Letter alias m.



N

Letter alias n.



Ng

Letter alias ng.



Ny

Letter alias ny.



O

Letter alias o.



Oe

Letter alias oe.



P

Letter alias p.



R

Letter alias r.



Rh

Letter alias rh.



S

Letter alias s.



Sbm

Letter alias sbm.



Sh

Letter alias sh.



T

Letter alias t.



U

Letter alias u.



Ue

Letter alias ue.



W

Letter alias w.



Y

Letter alias y.



Z

Letter alias z.



Zr

Letter alias zr.

Implementations

Source

impl Alias

pub const ALL: [Alias; 42]

Every variant, in declaration (sorted contract-name) order.

pub const fn as_str(self) -> &'static str

The contract name used by the Python API, the CLI and the data files.